==> RSTouchscreenNG-1.4.11.zip: RSTouchscreenNG/projects/pages/src/lib/last-prints.component.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {
    RepetierServer,
    PrinterState,
    PrintersState,
    RepetierState,
    ConnectionHandler,
    PrinterAction,
    LastPrintFile
} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {Store} from "@ngrx/store";
import {RSSelect} from "front-ui";

@Component({
    // eslint-disable-next-line @angular-eslint/component-selector
    selector: "rs-last-prints",
    // template: `<div>Hallo</div>`,
    template: `
      <rs-page>
        <rs-side>
          <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
        </rs-side>
        <rs-side>
          <rs-sideicon *rsIfPrinting="true" title="<?php _('Print') ?>" icon="rs rs-print" link="/print-status"></rs-sideicon>
        </rs-side>
        <rs-side>
          <rs-sideicon icon="rs rs-file-gcode" title="<?php _('G-Codes') ?>" link="/gcodes"></rs-sideicon>
        </rs-side>
        <main>
          <div>
            <rs-headline><i class="rs rs-last-prints-g"></i> {{tLastPrints}}</rs-headline>
            <div class="content-h1" rsDrag>
              <h2><?php _('Print or Queue') ?></h2>
              <div class="entry-list" *ngIf="!flashTimer">
                <div class="entry" *ngFor="let f of printer?.lastPrints" (rsClick)="printGCode(f)">
                  <h3>{{f.name}}</h3>
                  <p>{{f.size | byte}} - {{(f.time * 1000) | dateTimeShort}}</p>
                </div>
              </div>

              <div *ngIf="printer?.lastPrints.length===0 && !flashTimer" class="alert info margin">
                {{tLastPrintsIsEmpty}}
              </div>

              <div *ngIf="!!flashTimer" class="alert info margin">
                {{flashMessage}}
              </div>
            </div>
          </div>
        </main>
      </rs-page>
    `
})
export class LastPrintsComponent implements OnDestroy {
    printer: PrinterState;
    printers$: Observable<PrintersState>;
    private printersSubscription: SubscriptionLike;
    tLastPrintsIsEmpty = "<?php _('No recent prints available!') ?>";
    tLastPrints = "<?php _('Last Prints') ?>";
    flashTimer: any = undefined;
    flashMessage = "";
    constructor(public server: RepetierServer,
                private store: Store<RepetierState>,
                private connectionHandler: ConnectionHandler,
                private rsselect: RSSelect,
                private printerAction: PrinterAction) {
        this.printers$ = store.select("printers");
        this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
            if (p.active) {
                this.printer = p.printers[p.active];
            } else {
                this.printer = undefined;
            }
        });
    }

    ngOnDestroy(): void {
        this.printersSubscription.unsubscribe();
    }

    printGCode(gc: LastPrintFile) {
        const list = [
            {id: "print", name: "<?php _('Print') ?>", icon: "rs rs-print"},
            {id: "queue", name: "<?php _('Queue') ?>", icon: "rs rs-queue"}
        ];
        this.rsselect.select(list, "name", gc.name).then((sel: any) => {
            console.log("Selected", sel);
            this.connectionHandler.send("lastPrintAction", {file: gc.name, action: sel.id}, this.printer.slug)
                .then((r: any) => {
                    console.log("Result", r);
                    this.flashMessage = (r.queued ? "<?php _('File queued:') ?> " : "<?php _('Print started: ') ?>") + gc.name;
                    this.flashTimer = setTimeout(() => {
                        this.flashTimer = undefined;
                    }, 4000);
                });
        }, () => {});
    }
}

==> RSTouchscreenNG-1.4.13.zip: RSTouchscreenNG/projects/pages/src/lib/last-prints.component.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {
    RepetierServer,
    PrinterState,
    PrintersState,
    RepetierState,
    ConnectionHandler,
    PrinterAction,
    LastPrintFile
} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {Store} from "@ngrx/store";
import {RSSelect} from "front-ui";

@Component({
    // eslint-disable-next-line @angular-eslint/component-selector
    selector: "rs-last-prints",
    // template: `<div>Hallo</div>`,
    template: `
      <rs-page>
        <rs-side>
          <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
        </rs-side>
        <rs-side>
          <rs-sideicon icon="rs rs-file-gcode" title="<?php _('G-Codes') ?>" link="/gcodes"></rs-sideicon>
        </rs-side>
        <rs-side *rsIfPrinting="true">
          <rs-sideicon title="<?php _('Print') ?>" icon="rs rs-print" link="/print-status"></rs-sideicon>
        </rs-side>
        <rs-side  *rsIfPrinting="false">
          <rs-icon *ngIf="(printer?.queue?.length>0) && printer?.config.general?.enableQueue" [counter]="printer?.queue?.length" icon="rs rs-queue" title="{{tPrintQueue}}" link="/print-queue"></rs-icon>
          <rs-empty-sideicon *ngIf="!((printer?.queue?.length>0) && printer?.config.general?.enableQueue)"></rs-empty-sideicon>
        </rs-side>
        <main>
          <div>
            <rs-headline><i class="rs rs-last-prints-g"></i> {{tLastPrints}}</rs-headline>
            <div class="content-h1" rsDrag>
              <h2><?php _('Print or Queue') ?></h2>
              <div class="entry-list" *ngIf="!flashTimer">
                <div class="entry" *ngFor="let f of printer?.lastPrints" (rsClick)="printGCode(f)">
                  <h3>{{f.name}}</h3>
                  <p>{{f.size | byte}} - {{(f.time * 1000) | dateTimeShort}}</p>
                </div>
              </div>

              <div *ngIf="printer?.lastPrints.length===0 && !flashTimer" class="alert info margin">
                {{tLastPrintsIsEmpty}}
              </div>

              <div *ngIf="!!flashTimer" class="alert info margin">
                {{flashMessage}}
              </div>
            </div>
          </div>
        </main>
      </rs-page>
    `
})
export class LastPrintsComponent implements OnDestroy {
    printer: PrinterState;
    printers$: Observable<PrintersState>;
    private printersSubscription: SubscriptionLike;
    tLastPrintsIsEmpty = "<?php _('No recent prints available!') ?>";
    tLastPrints = "<?php _('Last Prints') ?>";
    tPrintQueue = "<?php _('Print Queue') ?>";
    flashTimer: any = undefined;
    flashMessage = "";
    constructor(public server: RepetierServer,
                private store: Store<RepetierState>,
                private connectionHandler: ConnectionHandler,
                private rsselect: RSSelect,
                private printerAction: PrinterAction) {
        this.printers$ = store.select("printers");
        this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
            if (p.active) {
                this.printer = p.printers[p.active];
            } else {
                this.printer = undefined;
            }
        });
    }

    ngOnDestroy(): void {
        this.printersSubscription.unsubscribe();
    }

    printGCode(gc: LastPrintFile) {
        const list = [
            {id: "print", name: "<?php _('Print') ?>", icon: "rs rs-print"},
            {id: "queue", name: "<?php _('Queue') ?>", icon: "rs rs-queue"}
        ];
        this.rsselect.select(list, "name", gc.name).then((sel: any) => {
            console.log("Selected", sel);
            this.connectionHandler.send("lastPrintAction", {file: gc.name, action: sel.id}, this.printer.slug)
                .then((r: any) => {
                    console.log("Result", r);
                    this.flashMessage = (r.queued ? "<?php _('File queued:') ?> " : "<?php _('Print started: ') ?>") + gc.name;
                    this.flashTimer = setTimeout(() => {
                        this.flashTimer = undefined;
                    }, 4000);
                });
        }, () => {});
    }

  protected readonly undefined = undefined;
}
